==> pmml-model-1.0.8-sources.jar: org/dmg/pmml/KohonenMap.java <==

package org.dmg.pmml;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.XmlType;
import com.sun.xml.bind.Locatable;
import com.sun.xml.bind.annotation.XmlLocation;
import org.jvnet.jaxb2_commons.lang.Equals;
import org.jvnet.jaxb2_commons.lang.EqualsStrategy;
import org.jvnet.jaxb2_commons.lang.HashCode;
import org.jvnet.jaxb2_commons.lang.HashCodeStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBEqualsStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBHashCodeStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;
import org.jvnet.jaxb2_commons.locator.util.LocatorUtils;
import org.xml.sax.Locator;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_1}Extension" maxOccurs="unbounded" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="coord1" type="{http://www.w3.org/2001/XMLSchema}float" />
 *       &lt;attribute name="coord2" type="{http://www.w3.org/2001/XMLSchema}float" />
 *       &lt;attribute name="coord3" type="{http://www.w3.org/2001/XMLSchema}float" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "extensions"
})
@XmlRootElement(name = "KohonenMap")
public class KohonenMap
    extends PMMLObject
    implements Locatable, Equals, HashCode, ToString
{

    @XmlElement(name = "Extension")
    protected List<Extension> extensions;
    @XmlAttribute(name = "coord1")
    protected Float coord1;
    @XmlAttribute(name = "coord2")
    protected Float coord2;
    @XmlAttribute(name = "coord3")
    protected Float coord3;
    @XmlLocation
    @XmlTransient
    protected Locator locator;

    /**
     * Gets the value of the extensions property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the extensions property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getExtensions().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Extension }
     * 
     * 
     */
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    /**
     * Gets the value of the coord1 property.
     * 
     * @return
     *     possible object is
     *     {@link Float }
     *     
     */
    public Float getCoord1() {
        return coord1;
    }

    /**
     * Sets the value of the coord1 property.
     * 
     * @param value
     *     allowed object is
     *     {@link Float }
     *     
     */
    public void setCoord1(Float value) {
        this.coord1 = value;
    }

    /**
     * Gets the value of the coord2 property.
     * 
     * @return
     *     possible object is
     *     {@link Float }
     *     
     */
    public Float getCoord2() {
        return coord2;
    }

    /**
     * Sets the value of the coord2 property.
     * 
     * @param value
     *     allowed object is
     *     {@link Float }
     *     
     */
    public void setCoord2(Float value) {
        this.coord2 = value;
    }

    /**
     * Gets the value of the coord3 property.
     * 
     * @return
     *     possible object is
     *     {@link Float }
     *     
     */
    public Float getCoord3() {
        return coord3;
    }

    /**
     * Sets the value of the coord3 property.
     * 
     * @param value
     *     allowed object is
     *     {@link Float }
     *     
     */
    public void setCoord3(Float value) {
        this.coord3 = value;
    }

    public boolean equals(ObjectLocator thisLocator, ObjectLocator thatLocator, Object object, EqualsStrategy strategy) {
        if (!(object instanceof KohonenMap)) {
            return false;
        }
        if (this == object) {
            return true;
        }
        if (!super.equals(thisLocator, thatLocator, object, strategy)) {
            return false;
        }
        final KohonenMap that = ((KohonenMap) object);
        {
            List<Extension> lhsExtensions;
            lhsExtensions = (((this.extensions!= null)&&(!this.extensions.isEmpty()))?this.getExtensions():null);
            List<Extension> rhsExtensions;
            rhsExtensions = (((that.extensions!= null)&&(!that.extensions.isEmpty()))?that.getExtensions():null);
            if (!strategy.equals(LocatorUtils.property(thisLocator, "extensions", lhsExtensions), LocatorUtils.property(thatLocator, "extensions", rhsExtensions), lhsExtensions, rhsExtensions)) {
                return false;
            }
        }
        {
            Float lhsCoord1;
            lhsCoord1 = this.getCoord1();
            Float rhsCoord1;
            rhsCoord1 = that.getCoord1();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "coord1", lhsCoord1), LocatorUtils.property(thatLocator, "coord1", rhsCoord1), lhsCoord1, rhsCoord1)) {
                return false;
            }
        }
        {
            Float lhsCoord2;
            lhsCoord2 = this.getCoord2();
            Float rhsCoord2;
            rhsCoord2 = that.getCoord2();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "coord2", lhsCoord2), LocatorUtils.property(thatLocator, "coord2", rhsCoord2), lhsCoord2, rhsCoord2)) {
                return false;
            }
        }
        {
            Float lhsCoord3;
            lhsCoord3 = this.getCoord3();
            Float rhsCoord3;
            rhsCoord3 = that.getCoord3();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "coord3", lhsCoord3), LocatorUtils.property(thatLocator, "coord3", rhsCoord3), lhsCoord3, rhsCoord3)) {
                return false;
            }
        }
        return true;
    }

    public boolean equals(Object object) {
        final EqualsStrategy strategy = JAXBEqualsStrategy.INSTANCE;
        return equals(null, null, object, strategy);
    }

    public int hashCode(ObjectLocator locator, HashCodeStrategy strategy) {
        int currentHashCode = super.hashCode(locator, strategy);
        {
            List<Extension> theExtensions;
            theExtensions = (((this.extensions!= null)&&(!this.extensions.isEmpty()))?this.getExtensions():null);
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "extensions", theExtensions), currentHashCode, theExtensions);
        }
        {
            Float theCoord1;
            theCoord1 = this.getCoord1();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "coord1", theCoord1), currentHashCode, theCoord1);
        }
        {
            Float theCoord2;
            theCoord2 = this.getCoord2();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "coord2", theCoord2), currentHashCode, theCoord2);
        }
        {
            Float theCoord3;
            theCoord3 = this.getCoord3();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "coord3", theCoord3), currentHashCode, theCoord3);
        }
        return currentHashCode;
    }

    public int hashCode() {
        final HashCodeStrategy strategy = JAXBHashCodeStrategy.INSTANCE;
        return this.hashCode(null, strategy);
    }

    public Locator sourceLocation() {
        return locator;
    }

    public void setSourceLocation(Locator newLocator) {
        locator = newLocator;
    }

    public String toString() {
        final ToStringStrategy strategy = JAXBToStringStrategy.INSTANCE;
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy strategy) {
        super.appendFields(locator, buffer, strategy);
        {
            List<Extension> theExtensions;
            theExtensions = (((this.extensions!= null)&&(!this.extensions.isEmpty()))?this.getExtensions():null);
            strategy.appendField(locator, this, "extensions", buffer, theExtensions);
        }
        {
            Float theCoord1;
            theCoord1 = this.getCoord1();
            strategy.appendField(locator, this, "coord1", buffer, theCoord1);
        }
        {
            Float theCoord2;
            theCoord2 = this.getCoord2();
            strategy.appendField(locator, this, "coord2", buffer, theCoord2);
        }
        {
            Float theCoord3;
            theCoord3 = this.getCoord3();
            strategy.appendField(locator, this, "coord3", buffer, theCoord3);
        }
        return buffer;
    }

}

==> pmml-model-1.0.14-sources.jar: org/dmg/pmml/KohonenMap.java <==

package org.dmg.pmml;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.XmlType;
import com.sun.xml.bind.Locatable;
import com.sun.xml.bind.annotation.XmlLocation;
import org.xml.sax.Locator;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_1}Extension" maxOccurs="unbounded" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="coord1" type="{http://www.w3.org/2001/XMLSchema}float" />
 *       &lt;attribute name="coord2" type="{http://www.w3.org/2001/XMLSchema}float" />
 *       &lt;attribute name="coord3" type="{http://www.w3.org/2001/XMLSchema}float" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "extensions"
})
@XmlRootElement(name = "KohonenMap")
public class KohonenMap
    extends PMMLObject
    implements Locatable
{

    @XmlElement(name = "Extension")
    protected List<Extension> extensions;
    @XmlAttribute(name = "coord1")
    protected Float coord1;
    @XmlAttribute(name = "coord2")
    protected Float coord2;
    @XmlAttribute(name = "coord3")
    protected Float coord3;
    @XmlLocation
    @XmlTransient
    protected Locator locator;

    /**
     * Gets the value of the extensions property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the extensions property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getExtensions().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Extension }
     * 
     * 
     */
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    /**
     * Gets the value of the coord1 property.
     * 
     * @return
     *     possible object is
     *     {@link Float }
     *     
     */
    public Float getCoord1() {
        return coord1;
    }

    /**
     * Sets the value of the coord1 property.
     * 
     * @param value
     *     allowed object is
     *     {@link Float }
     *     
     */
    public void setCoord1(Float value) {
        this.coord1 = value;
    }

    /**
     * Gets the value of the coord2 property.
     * 
     * @return
     *     possible object is
     *     {@link Float }
     *     
     */
    public Float getCoord2() {
        return coord2;
    }

    /**
     * Sets the value of the coord2 property.
     * 
     * @param value
     *     allowed object is
     *     {@link Float }
     *     
     */
    public void setCoord2(Float value) {
        this.coord2 = value;
    }

    /**
     * Gets the value of the coord3 property.
     * 
     * @return
     *     possible object is
     *     {@link Float }
     *     
     */
    public Float getCoord3() {
        return coord3;
    }

    /**
     * Sets the value of the coord3 property.
     * 
     * @param value
     *     allowed object is
     *     {@link Float }
     *     
     */
    public void setCoord3(Float value) {
        this.coord3 = value;
    }

    public Locator sourceLocation() {
        return locator;
    }

    public void setSourceLocation(Locator newLocator) {
        locator = newLocator;
    }

}
